@@ -16,7 +16,7 @@
 read_pest <- function(file_name,col_types=NULL,col_names=NULL){
 
   # Read in raw data from file
-  raw_lines <- readLines(file_name) %>%
+  raw_lines <- readLines(file_name, warn = FALSE) %>%
     str_subset('^(?!\032) *([^ ]+)') # exclude lines that are all spaces or lines with EOF in initial position
 
   start_end <- matrix(nrow=6,ncol=2)
